@@ -21,6 +21,7 @@ class Constant:
     BASE_PATH = ""
     PROJECT_PATH = ""  # 待测试的小程序项目路径
     DEV_TOOL_PATH = ""  # 微信开发者工具路径
+    ALLURE_TOOL = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'tools/allure-2.14.0/bin/allure')
 
     @property
     def SRC_PATH(self):
@@ -42,10 +43,6 @@ class Constant:
     def TOOL_PATH(self):
         return os.path.join(self.SRC_PATH, 'test_pic')
 
-    @property
-    def ALLURE_TOOL_PATH(self):
-        return os.path.join(self.TOOL_PATH, 'allure-2.14.0/bin')
-
     def __init__(self):
         if Constant.BASE_PATH:
             for i in [self.LOG_PATH, self.REPORT_PATH, self.TEST_PIC]:
