@@ -15,7 +15,7 @@ import pytest
 from allure_commons.model2 import TestResult, TestResultContainer
 
 from .allureoperator import attach_png
-from .constant import TEST_PIC
+from .constant import Constant
 from .logoperator import LogOperator
 from .mini import Mini
 
@@ -38,7 +38,7 @@ def pytest_runtest_makereport(item, call):
         for k, v in item.funcargs.items():
             try:
                 if hasattr(v, 'native'):
-                    attach_png(f'{TEST_PIC}/{int(time.time())}.png', "失败截图", v)
+                    attach_png(f'{Constant().TEST_PIC}/{int(time.time())}.png', "失败截图", v)
                     break
             except Exception as e:
                 logger.error(f"失败截图异常:{e}")
@@ -54,7 +54,7 @@ def pytest_assume_fail(lineno, entry):
             try:
                 for k, v in i.frame.f_locals.items():
                     if hasattr(v, 'native'):
-                        attach_png(f'{TEST_PIC}/{int(time.time())}.png', f"失败截图_{int(time.time())}", v)
+                        attach_png(f'{Constant().TEST_PIC}/{int(time.time())}.png', f"失败截图_{int(time.time())}", v)
                         break
             except Exception as e:
                 logger.error(f"失败截图异常:{e}")
